#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-repl
version:              0.1.2
visibility:           public
id:                   hslua-repl-0.1.2-CUZQv9bGZN4IH2uYe6JCQZ
key:                  hslua-repl-0.1.2-CUZQv9bGZN4IH2uYe6JCQZ
license:              MIT
copyright:            © 2023-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Isocline-based Lua REPL
description:          An embeddable Lua REPL built with Isocline and HsLua.
category:             Foreign
abi:                  9c1472be998761192e41d230d7e3d4b7
exposed:              True
exposed-modules:      HsLua.REPL
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-repl-0.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-repl-0.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-repl-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-repl
hs-libraries:         HShslua-repl-0.1.2-CUZQv9bGZN4IH2uYe6JCQZ
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    hslua-core-2.3.2.1-3tsNfZ2PPMpIrGoJYp3SDj
    isocline-1.0.9-2KCnLAEX6LA5YHxtEpLDUO
    lua-2.3.4-20P8t9Lp5PTB2kg5tNKfBD text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-hslua-repl/html/hslua-repl.haddock
haddock-html:         /usr/share/doc/haskell-hslua-repl/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

